﻿using System;
using System.IO;
using Keyoti.RapidSpell.Wpf;

namespace SpellChecker {
    public class KeyotiConfigurator {

        //Rename Keyoti's dictionaries to RapidSpellDictXX.dict, where XX is the 2-character language code, and place dictionaries in ExpertShare directory
        private const string LanguageCode = "EN";
        private static readonly string SpellingDictionaryName = String.Format("RapidSpellDict{0}.dict", LanguageCode);
        private static readonly string FullDictPath = GetFullPath(SpellingDictionaryName);

        /// <summary>
        /// Creates a new instance of the user dictionary.
        /// </summary>
        public static CustomUserDictionary CreateUserDictionary() {
            return new CustomUserDictionary("AderantCustomDictionary");
        }

        /// <summary>
        /// Configures the checker engine with default settings.
        /// </summary>
        public static void ConfigureRapidSpellAsYouType(RapidSpellAsYouType sayt, CustomUserDictionary customDictionary) {
            sayt.OptionsEnabled = false;
            sayt.ShowSuggestionsContextMenu = false;
            sayt.DictFilePath = FullDictPath;

            switch (LanguageCode) {
                case "NL" :
                    sayt.GUILanguage = LanguageType.DUTCH;
                    sayt.LanguageParser = LanguageType.DUTCH;
                    break;
                case "FR":
                    sayt.GUILanguage = LanguageType.FRENCH;
                    sayt.LanguageParser = LanguageType.FRENCH;
                    break;
                case "DE":
                    sayt.GUILanguage = LanguageType.GERMAN;
                    sayt.LanguageParser = LanguageType.GERMAN;
                    break;
                case "IT":
                    sayt.GUILanguage = LanguageType.ITALIAN;
                    sayt.LanguageParser = LanguageType.ITALIAN;
                    break;
                case "PT":
                    sayt.GUILanguage = LanguageType.PORTUGUESE;
                    sayt.LanguageParser = LanguageType.PORTUGUESE;
                    break;
                case "ES":
                    sayt.GUILanguage = LanguageType.SPANISH;
                    sayt.LanguageParser = LanguageType.SPANISH;
                    break;
                default :
                    sayt.GUILanguage = LanguageType.ENGLISH;
                    sayt.LanguageParser = LanguageType.ENGLISH;
                    break;
            }

            sayt.AddMenuText = "Add to Dictionary";
            sayt.IgnoreAllMenuText = "Ignore All";
            sayt.RemoveDuplicateWordText = "Remove duplicate word";
            sayt.RapidSpellChecker = new RapidSpellChecker();
            ConfigureCheckerEngine(sayt.RapidSpellChecker, customDictionary);
        }

        /// <summary>
        /// Configures the checker engine with default settings.
        /// </summary>
        public static void ConfigureRapidSpellDialog(RapidSpellDialog sd, CustomUserDictionary customDictionary) {
            sd.OptionsEnabled = false;
            ConfigureCheckerEngine(sd.CheckerEngine, customDictionary);
            sd.DictFilePath = FullDictPath;

            switch (LanguageCode) {
                case "NL" :
                    sd.GUILanguage = LanguageType.DUTCH;
                    break;
                case "FR":
                    sd.GUILanguage = LanguageType.FRENCH;
                    break;
                case "DE":
                    sd.GUILanguage = LanguageType.GERMAN;
                    break;
                case "IT":
                    sd.GUILanguage = LanguageType.ITALIAN;
                    break;
                case "PT":
                    sd.GUILanguage = LanguageType.PORTUGUESE;
                    break;
                case "ES":
                    sd.GUILanguage = LanguageType.SPANISH;
                    break;
                default :
                    sd.GUILanguage = LanguageType.ENGLISH;
                    break;
            }
        }

        /// <summary>
        /// Configures the checker engine with default settings.
        /// </summary>
        public static void ConfigureCheckerEngine(ICheckerEngine engine, CustomUserDictionary customDictionary) {
            engine.SetUserDictionary(customDictionary);
            engine.DictFilePath = FullDictPath;

            switch (LanguageCode) {
                case "NL":
                    engine.LanguageParser = LanguageType.DUTCH;
                    break;
                case "FR":
                    engine.LanguageParser = LanguageType.FRENCH;
                    break;
                case "DE":
                    engine.LanguageParser = LanguageType.GERMAN;
                    break;
                case "IT":
                    engine.LanguageParser = LanguageType.ITALIAN;
                    break;
                case "PT":
                    engine.LanguageParser = LanguageType.PORTUGUESE;
                    break;
                case "ES":
                    engine.LanguageParser = LanguageType.SPANISH;
                    break;
                default:
                    engine.LanguageParser = LanguageType.ENGLISH;
                    break;
            }
        }

        private static string GetFullPath(string dictName) {
            //string path = Installation.FrameworkPath(dictName);
            const string path = "C:\\FakeFolder";
            string fullPath = null;
            if (!string.IsNullOrEmpty(path)) {
                fullPath = Path.Combine(path, dictName);
            }
            if (string.IsNullOrWhiteSpace(fullPath) || !File.Exists(fullPath)) {
                fullPath = null;
            }
            return fullPath;
        }

    }
}
